@@ -27,16 +27,52 @@ def test_quote_not_allowed(quote):
         quote('%HH')
 
 
+def test_quote_not_allowed_non_strict(quote):
+    assert quote('%HH', strict=False) == '%25HH'
+
+
 def test_quote_unfinished(quote):
     with pytest.raises(ValueError):
         quote('%F%F')
 
 
+def test_quote_unfinished_tail_percent(quote):
+    with pytest.raises(ValueError):
+        quote('%')
+
+
+def test_quote_unfinished_tail_percent_non_strict(quote):
+    assert quote('%', strict=False) == '%25'
+
+
+def test_quote_unfinished_tail(quote):
+    with pytest.raises(ValueError):
+        quote('%2')
+
+
+def test_quote_unfinished_tail_non_strict(quote):
+    assert quote('%2', strict=False) == '%252'
+
+
 def test_quote_from_bytes(quote):
     assert quote('archaeological arcana') == 'archaeological%20arcana'
     assert quote('') == ''
 
 
+def test_quate_broken_unicode(quote):
+    with pytest.raises(UnicodeEncodeError):
+        quote('j\x1a\udcf4q\udcda/\udc97g\udcee\udccb\x0ch\udccb'
+              '\x18\udce4v\x1b\udce2\udcce\udccecom/y\udccepj\x16')
+
+
+def test_quate_ignore_broken_unicode(quote):
+    s = quote('j\x1a\udcf4q\udcda/\udc97g\udcee\udccb\x0ch\udccb'
+              '\x18\udce4v\x1b\udce2\udcce\udccecom/y\udccepj\x16',
+              strict=False)
+
+    assert s == 'j%1Aq%2Fg%0Ch%18v%1Bcom%2Fypj%16'
+
+
 def test_unquote_to_bytes(unquote):
     assert unquote('abc%20def') == 'abc def'
     assert unquote('') == ''
@@ -112,6 +148,7 @@ def test_quoting_space(quote):
 
 
 def test_quoting_plus(quote):
+    assert quote('alpha+beta gamma', qs=False) == 'alpha+beta%20gamma'
     assert quote('alpha+beta gamma', qs=True) == 'alpha%2Bbeta+gamma'
     assert quote('alpha+beta gamma', safe='+', qs=True) == 'alpha+beta+gamma'
 
@@ -149,7 +186,7 @@ def test_unquoting(num, unquote):
     expect = chr(num)
     result = unquote(given)
     assert expect == result
-    if expect not in '+=&':
+    if expect not in '+=&;':
         result = unquote(given, qs=True)
         assert expect == result
 
@@ -233,6 +270,17 @@ def test_quote_unquoted(quote):
     assert quote('%41') == 'A'
 
 
+def test_quote_space(quote):
+    assert quote(' ', strict=False) == '%20'  # NULL
+
+
+# test to see if this would work to fix
+# coverage on this file.
+def test_quote_percent_last_character(quote):
+    # % is last character in this case.
+    assert quote('%', strict=False) == '%25'
+
+
 def test_unquote_unsafe(unquote):
     assert unquote('%40', unsafe='@') == '%40'
 
@@ -285,6 +333,10 @@ def test_requote_sub_delims(quote):
     assert quote("%21%24%26%27%28%29%2A%2B%2C%3B%3D") == "!$&'()*+,;="
 
 
+def test_unquoting_plus(unquote):
+    assert unquote('a+b', qs=False) == 'a+b'
+
+
 def test_unquote_plus_to_space(unquote):
     assert unquote('a+b', qs=True) == 'a b'
 
